@@ -11,9 +11,11 @@ from cognite.client.data_classes.assets import (
 from cognite.client.data_classes.contextualization import (
     ContextualizationJob,
     ContextualizationJobList,
+    ContextualizationJobType,
     EntityMatchingModel,
     EntityMatchingModelList,
     EntityMatchingModelUpdate,
+    JobStatus,
 )
 from cognite.client.data_classes.data_sets import DataSet, DataSetAggregate, DataSetFilter, DataSetList, DataSetUpdate
 from cognite.client.data_classes.datapoints import Datapoint, Datapoints, DatapointsList, DatapointsQuery
@@ -64,6 +66,15 @@ from cognite.client.data_classes.sequences import (
     SequenceUpdate,
 )
 from cognite.client.data_classes.shared import AggregateResult, AggregateUniqueValuesResult, TimestampRange
+from cognite.client.data_classes.templates import (
+    ConstantResolver,
+    TemplateGroup,
+    TemplateGroupList,
+    TemplateGroupVersion,
+    TemplateGroupVersionList,
+    TemplateInstance,
+    TemplateInstanceList,
+)
 from cognite.client.data_classes.three_d import (
     BoundingBox3D,
     RevisionCameraProperties,
